==> swish++_1.1b3.orig.tar.gz: swish++-1.1b3/word_index.c <==
/*
**	SWISH++
**	word_index.c
**
**	Copyright (C) 1998  Paul J. Lucas
**
**	This program is free software; you can redistribute it and/or modify
**	it under the terms of the GNU General Public License as published by
**	the Free Software Foundation; either version 2 of the License, or
**	(at your option) any later version.
** 
**	This program is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
** 
**	You should have received a copy of the GNU General Public License
**	along with this program; if not, write to the Free Software
**	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

// local
#include "fake_ansi.h"
#include "word_index.h"

//*****************************************************************************
//
// SYNOPSIS
//
	void word_index::set_index_file( file_vector<char> const &file )
//
// DESCRIPTION
//
//	Set the index file to use by setting data members to the proper
//	positions withing the index file.
//
// CAVEAT
//
//	Ideally, this function would be part of the constructor, but the name
//	of the index file can be passed in via the command line and that isn't
//	parsed until after the instance is constructed.
//
// SEE ALSO
//
//	index.c		write_full_index() -- format of index file
//
//*****************************************************************************
{
	begin_ = file.begin();
	long const *const p = REINTERPRET_CAST( long const* )( begin_ );
	num_words_ = p[ 0 ];
	offset_ = STATIC_CAST( off_t const* )( &p[ 1 ] );
}

==> swish++_3.0.3.orig.tar.gz: swish++-3.0.3/word_index.c <==
/*
**	SWISH++
**	word_index.c
**
**	Copyright (C) 1998  Paul J. Lucas
**
**	This program is free software; you can redistribute it and/or modify
**	it under the terms of the GNU General Public License as published by
**	the Free Software Foundation; either version 2 of the License, or
**	(at your option) any later version.
** 
**	This program is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
** 
**	You should have received a copy of the GNU General Public License
**	along with this program; if not, write to the Free Software
**	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

// local
#include "util.h"
#include "word_index.h"

//*****************************************************************************
//
// SYNOPSIS
//
	void word_index::set_index_file( file_vector<char> const &file, int i )
//
// DESCRIPTION
//
//	Set the index file to use by setting data members to the proper
//	positions within the index file.
//
// CAVEAT
//
//	Ideally, this function would be part of the constructor, but the name
//	of the index file can be passed in via the command line and that isn't
//	parsed until after the instance is constructed.
//
// SEE ALSO
//
//	index.c		write_full_index() -- format of index file
//
//*****************************************************************************
{
	begin_ = file.begin();
	get_index_info( file, i, &num_words_, &offset_ );
}
